==> apache-artemis-2.33.0-source-release.tar.gz: apache-artemis-2.33.0/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/cursor/NonExistentPage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.core.paging.cursor;

/**
 * This is an internal exception.
 * In certain cases AfterCommit could try to decrease the reference counting on large messages.
 * But if the whole page is cleaned an exception could happen, which is ok on that path, and we need to identify it.
 */
public class NonExistentPage extends RuntimeException {

   public NonExistentPage() {
   }

   public NonExistentPage(String message) {
      super(message);
   }

   public NonExistentPage(String message, Throwable cause) {
      super(message, cause);
   }

   public NonExistentPage(Throwable cause) {
      super(cause);
   }

   public NonExistentPage(String message, Throwable cause, boolean enableSuppression, boolean writableStackTrace) {
      super(message, cause, enableSuppression, writableStackTrace);
   }
}

==> apache-artemis-2.42.0-source-release.tar.gz: apache-artemis-2.42.0/artemis-server/src/main/java/org/apache/activemq/artemis/core/paging/cursor/NonExistentPage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.core.paging.cursor;

/**
 * This is an internal exception. In certain cases AfterCommit could try to decrease the reference counting on large
 * messages. But if the whole page is cleaned an exception could happen, which is ok on that path, and we need to
 * identify it.
 */
public class NonExistentPage extends RuntimeException {

   public NonExistentPage() {
   }

   public NonExistentPage(String message) {
      super(message);
   }

   public NonExistentPage(String message, Throwable cause) {
      super(message, cause);
   }

   public NonExistentPage(Throwable cause) {
      super(cause);
   }

   public NonExistentPage(String message, Throwable cause, boolean enableSuppression, boolean writableStackTrace) {
      super(message, cause, enableSuppression, writableStackTrace);
   }
}
